specialize Package
==================

:mod:`specialize` Package
-------------------------

.. automodule:: numba.specialize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`comparisons` Module
-------------------------

.. automodule:: numba.specialize.comparisons
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
------------------------

.. automodule:: numba.specialize.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exttypes` Module
----------------------

.. automodule:: numba.specialize.exttypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`funccalls` Module
-----------------------

.. automodule:: numba.specialize.funccalls
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loopimpl` Module
----------------------

.. automodule:: numba.specialize.loopimpl
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loops` Module
-------------------

.. automodule:: numba.specialize.loops
    :members:
    :undoc-members:
    :show-inheritance:

